# Napistu Python Library

[![Documentation Status](https://readthedocs.org/projects/napistu/badge/?version=latest)](https://napistu.readthedocs.io/en/latest/?badge=latest)

This Python package hosts the majority of the algorithmic code for the [Napistu project](https://github.com/napistu/napistu).

## Setup

Napistu is available on [PyPI](https://pypi.org/project/napistu) so the recommended way to use it is just to pip install with:

```bash
pip install napistu
```

Alternatively, you can clone this repository and perform a local install. e.g., from this directory:

```bash
pip install .
```

## Documentation
- 📘 **Library Documentation**: [napistu.readthedocs.io](https://napistu.readthedocs.io)
- 🚸 **Project Documentation**: [napistu/wiki](https://github.com/napistu/napistu/wiki)

### Quick Links
- [Installation Guide](https://napistu.readthedocs.io/en/latest/installation.html)
- [API Reference](https://napistu.readthedocs.io/en/latest/api.html)
- [Usage Examples](https://napistu.readthedocs.io/en/latest/usage.html)
